using Plugin.Maui.Audio;
using MusiLib.Model;

namespace MusiLib.Views;

public partial class Accueil : ContentPage, IAllowClick
{

    public Manager MyManager => (App.Current as App).MyManager;

    private List<Partition> partitionsInitiales;

    public Accueil()
	{
		InitializeComponent();
        chargerPartitions();
        BindingContext = MyManager;
    }

    private void GoToFavorisButton(object sender, EventArgs e)
    {
        if (!IAllowClick.AllowTap) return;
        else IAllowClick.AllowTap = false;

        Navigation.PushAsync(new Favoris());

        IAllowClick.ResumeTap();
    }

    private void GoToPartitionButton(object sender, EventArgs e)
    {
        if (!IAllowClick.AllowTap) return;
        else IAllowClick.AllowTap = false;

        var button = (ImageButton)sender;
        var idAutomation = button.AutomationId;

        if (int.TryParse(idAutomation, out int id))
        {
            Navigation.PushAsync(new PartitionView(id));
        }


        IAllowClick.ResumeTap();
    }


    private void chargerPartitions()
    {
        partitionsInitiales = MyManager.partitions.ToList();

        int imagesParLigne = 3;
        int indice = 0;

        for (int i = 0; i < MyManager.partitions.Count; i++)
        {
            Model.Partition partitions = MyManager.partitions[i];

            ImageButton imageButton = new ImageButton
            {
                Source = partitions.Image[0],
                WidthRequest = 175,
                HeightRequest = 175,
                AutomationId = indice.ToString(),
            };

            imageButton.Clicked += GoToPartitionButton;

            int ligne = 1 + (indice / imagesParLigne);
            int colonne = indice % imagesParLigne;

            imageButton.Margin = GetImageButtonMargin(colonne);

            Grid.SetRow(imageButton, ligne);
            Grid.SetColumn(imageButton, colonne);
            grille.Children.Add(imageButton);

            indice++;
        }
    }

    private Thickness GetImageButtonMargin(int colonne)
    {
        if (colonne == 0)
        {
            return new Thickness(30, 0, 0, 0);
        }
        else if (colonne == 1)
        {
            return new Thickness(90, 0, 0, 0);
        }
        else
        {
            return new Thickness(150, 0, 0, 0);
        }
    }

    private void SearchBar_TextChanged(object sender, TextChangedEventArgs e)
    {
        string texteRecherche = e.NewTextValue;

        MyManager.partitions.Clear();

        foreach (Model.Partition partition in partitionsInitiales)
        {
            if (partition.Nom.ToLower().Contains(texteRecherche.ToLower()))
            {
                MyManager.partitions.Add(partition);
            }
        }
    }
}